==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-appearance/lxqt-config-appearance_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../../../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Tipus de lletra</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Tipus de lletra predeterminat per a la interfície d&apos;usuari</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Nom del tipus de lletra:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Estil:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Mida del punt:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Negreta</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Cursiva</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Cursiva en negreta</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Els següents ajusts únicament tindran efecte amb les aplicacions iniciades a partir d&apos;ara</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Utilitza els tipus de lletres amb antialiàsing</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Etil del contorn del tipus de lletra:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="118"/>
        <location filename="../../../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Sense</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Lleu</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Mitjà</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Complet</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Contorn del tipus de lletra</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Resolució (PPP):</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Contorn automàtic</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Antialiàsing dels subpíxels:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuració de l&apos;aparença de LXQt</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Tema de les icones</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>Tema de LXQt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="44"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuració de l&apos;aparença de LXQt</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="50"/>
        <source>Widget Style</source>
        <translation>Estil dels estris</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="54"/>
        <source>Icons Theme</source>
        <translation>Tema de les icones</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="58"/>
        <source>LXQt Theme</source>
        <translation>Tema de LXQt</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="62"/>
        <source>Font</source>
        <translation>Tipus de lletra</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="67"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../../../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation>Estil dels estris</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="54"/>
        <source>Toolbar button style:</source>
        <translation>Estil del botó de la barra d&apos;eines:</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="62"/>
        <source>Only display the icon</source>
        <translation>Mostra únicament la icona</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="67"/>
        <source>Only display the text</source>
        <translation>Mostra únicament el text</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="72"/>
        <source>The text appears beside the icon</source>
        <translation>El text apareix al costat de la icona</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="77"/>
        <source>The text appears under the icon</source>
        <translation>El text apareix a sota de la icona</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="82"/>
        <source>Default</source>
        <translation>Predeterminat</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="90"/>
        <source>Activate item on single click</source>
        <translation>Activa l&apos;ítem amb un sol clic</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-config/lxqt-config-appearance/lxqt-config-appearance_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../../../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Lletra</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Lletra predeterminada per a la interfície d&apos;usuari</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Nom de la lletra:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Estil:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Mida del punt:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Negreta</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Cursiva</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Cursiva en negreta</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Els següents ajusts únicament tindran efecte amb les aplicacions iniciades a partir d&apos;ara</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Utilitza les lletres amb antialiàsing</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Estil del contorn de la lletra:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="118"/>
        <location filename="../../../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Sense</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Lleu</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Mitjà</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Complet</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Contorn de la lletra</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Resolució (PPP):</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Contorn automàtic</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Antialiàsing dels subpíxels:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuració de l&apos;aparença de LXQt</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Tema de les icones</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>L&apos;extensió de KDE dels temes d&apos;icones XDG -&gt; FollowsColorScheme</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Acoloreix les icones en funció de l&apos;estil de l&apos;estri (paleta)</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>Tema de LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation>Anul·la el fons de pantalla definit per l&apos;usuari</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="57"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuració de l&apos;aparença de LXQt</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="63"/>
        <source>Widget Style</source>
        <translation>Estil dels estris</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="67"/>
        <source>Icons Theme</source>
        <translation>Tema de les icones</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="71"/>
        <source>LXQt Theme</source>
        <translation>Tema de LXQt</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="75"/>
        <source>Font</source>
        <translation>Lletra</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="80"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../../../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation>Estil dels estris</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="54"/>
        <source>Toolbar button style:</source>
        <translation>Estil del botó de la barra d&apos;eines:</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="62"/>
        <source>Only display the icon</source>
        <translation>Mostra únicament la icona</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="67"/>
        <source>Only display the text</source>
        <translation>Mostra únicament el text</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="72"/>
        <source>The text appears beside the icon</source>
        <translation>El text apareix al costat de la icona</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="77"/>
        <source>The text appears under the icon</source>
        <translation>El text apareix a sota de la icona</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="82"/>
        <source>Default</source>
        <translation>Predeterminat</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="90"/>
        <source>Activate item on single click</source>
        <translation>Activa l&apos;ítem amb un sol clic</translation>
    </message>
</context>
</TS>
